<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{cart2order}prestashop>cart2order_faa8d3a0de8d9157edfde87466d60a8c'] = 'Panier 2 Commande';
$_MODULE['<{cart2order}prestashop>cart2order_48ed57e86f59d514ef03879048aa67dc'] = 'Changez manuellement un Panier en commande';
$_MODULE['<{cart2order}prestashop>cart2order_580034e942d61c23826cb31dc2cb3c89'] = 'Panier #';
$_MODULE['<{cart2order}prestashop>cart2order_ebbb54dc31b64204a1706d194e5377d6'] = 'a été avec succès converti en commande';
$_MODULE['<{cart2order}prestashop>cart2order_f4d1ea475eaa85102e2b4e6d95da84bd'] = 'Confirmation';
$_MODULE['<{cart2order}prestashop>cart2order_c0354db4c387d0e76adda32fa32ab91c'] = 'Faites une donation';
$_MODULE['<{cart2order}prestashop>cart2order_bb8313bd83ed138f33fe278879804fb3'] = 'Si vous trouviez ce module utile et le voudriez faire une petite donation, cliquez sur le bouton de don ci-dessous. ';
$_MODULE['<{cart2order}prestashop>cart2order_e0229966abb07a9194c4ad71ef4825f2'] = 'Ce module te permet de convertir un panier de client en commande';
$_MODULE['<{cart2order}prestashop>cart2order_1f66fb16b72f225c37f06e92b328e847'] = 'PANIER ID';
$_MODULE['<{cart2order}prestashop>cart2order_979ee13f032c02b4652a4e3c3928d90b'] = 'CLIENT';
$_MODULE['<{cart2order}prestashop>cart2order_cd829d1e2067c54603e14874e66c6894'] = 'PANIER TOTAL';
$_MODULE['<{cart2order}prestashop>cart2order_633a6c7a6b9958f8174250094daf1e6a'] = 'DATE';
$_MODULE['<{cart2order}prestashop>cart2order_b842122b631d8b7013d43ed4a643a3d7'] = 'PAIEMENT';
$_MODULE['<{cart2order}prestashop>cart2order_07761044a74dbe2aaba8ee788390984c'] = 'Êtes vous sure que vous voulez convertir panier';
$_MODULE['<{cart2order}prestashop>cart2order_8913e29c6d39e65e9fa5516f680b4555'] = 'dans un commande de';
$_MODULE['<{cart2order}prestashop>cart2order_4ee29ca12c7d126654bd0e5275de6135'] = 'Liste';
